==> sdmx-registry-client-1.1.0-20130502.104956-2-sources.jar: org/gcube/datapublishing/sdmx/impl/model/SDMXRegistryDescriptorImpl.java <==
package org.gcube.datapublishing.sdmx.impl.model;

import org.gcube.datapublishing.sdmx.api.model.SDMXRegistryDescriptor;

public class SDMXRegistryDescriptorImpl implements SDMXRegistryDescriptor {
	
	String rest_url_V2_1 = null;
	String rest_url_V2 = null;
	String rest_url_V1 = null;
	
	String soap_url_V2_1 = null;
	String soap_url_V2 = null;
	String soap_url_V1 = null;
	
	public SDMXRegistryDescriptorImpl() {
	}
	
	private SDMXRegistryDescriptorImpl(String rest_url_V2_1, String rest_url_V2, String rest_url_V1,
			String soap_url_V2_1, String soap_url_V2, String soap_url_V1) {
		super();
		this.rest_url_V2_1 = rest_url_V2_1;
		this.rest_url_V2 = rest_url_V2;
		this.rest_url_V1 = rest_url_V1;
		this.soap_url_V2_1 = soap_url_V2_1;
		this.soap_url_V2 = soap_url_V2;
		this.soap_url_V1 = soap_url_V1;
	}
	public String getRest_url_V2_1() {
		return rest_url_V2_1;
	}
	public void setRest_url_V2_1(String rest_url_V2_1) {
		this.rest_url_V2_1 = rest_url_V2_1;
	}

	public String getRest_url_V2() {
		return rest_url_V2;
	}
	public void setRest_url_V2(String rest_url_V2) {
		this.rest_url_V2 = rest_url_V2;
	}

	public String getRest_url_V1() {
		return rest_url_V1;
	}
	public void setRest_url_V1(String rest_url_V1) {
		this.rest_url_V1 = rest_url_V1;
	}

	public String getSoap_url_V2_1() {
		return soap_url_V2_1;
	}
	public void setSoap_url_V2_1(String soap_url_V2_1) {
		this.soap_url_V2_1 = soap_url_V2_1;
	}

	public String getSoap_url_V2() {
		return soap_url_V2;
	}
	public void setSoap_url_V2(String soap_url_V2) {
		this.soap_url_V2 = soap_url_V2;
	}

	public String getSoap_url_V1() {
		return soap_url_V1;
	}
	public void setSoap_url_V1(String soap_url_V1) {
		this.soap_url_V1 = soap_url_V1;
	}
	
}

==> sdmx-registry-client-1.1.0-20130531.132157-4-sources.jar: org/gcube/datapublishing/sdmx/impl/model/SDMXRegistryDescriptorImpl.java <==
package org.gcube.datapublishing.sdmx.impl.model;

import org.gcube.datapublishing.sdmx.api.model.SDMXRegistryDescriptor;

public class SDMXRegistryDescriptorImpl implements SDMXRegistryDescriptor {
	
	String rest_url_V2_1 = null;
	String rest_url_V2 = null;
	String rest_url_V1 = null;
	
	String soap_url_V2_1 = null;
	String soap_url_V2 = null;
	String soap_url_V1 = null;
	
	public SDMXRegistryDescriptorImpl() {
	}
	
	public SDMXRegistryDescriptorImpl(String rest_url_V2_1, String rest_url_V2, String rest_url_V1,
			String soap_url_V2_1, String soap_url_V2, String soap_url_V1) {
		super();
		this.rest_url_V2_1 = rest_url_V2_1;
		this.rest_url_V2 = rest_url_V2;
		this.rest_url_V1 = rest_url_V1;
		this.soap_url_V2_1 = soap_url_V2_1;
		this.soap_url_V2 = soap_url_V2;
		this.soap_url_V1 = soap_url_V1;
	}
	public String getRest_url_V2_1() {
		return rest_url_V2_1;
	}
	public void setRest_url_V2_1(String rest_url_V2_1) {
		this.rest_url_V2_1 = rest_url_V2_1;
	}

	public String getRest_url_V2() {
		return rest_url_V2;
	}
	public void setRest_url_V2(String rest_url_V2) {
		this.rest_url_V2 = rest_url_V2;
	}

	public String getRest_url_V1() {
		return rest_url_V1;
	}
	public void setRest_url_V1(String rest_url_V1) {
		this.rest_url_V1 = rest_url_V1;
	}

	public String getSoap_url_V2_1() {
		return soap_url_V2_1;
	}
	public void setSoap_url_V2_1(String soap_url_V2_1) {
		this.soap_url_V2_1 = soap_url_V2_1;
	}

	public String getSoap_url_V2() {
		return soap_url_V2;
	}
	public void setSoap_url_V2(String soap_url_V2) {
		this.soap_url_V2 = soap_url_V2;
	}

	public String getSoap_url_V1() {
		return soap_url_V1;
	}
	public void setSoap_url_V1(String soap_url_V1) {
		this.soap_url_V1 = soap_url_V1;
	}
	
}
